@@ -6,10 +6,11 @@ Type annotations for appflow service client.
 Usage::
 
     ```python
-    import boto3
-    from mypy_boto3_appflow import AppflowClient
+    from boto3.session import Session
+    from mypy_boto3_appflow.client import AppflowClient
 
-    client: AppflowClient = boto3.client("appflow")
+    session = Session()
+    client: AppflowClient = session.client("appflow")
     ```
 """
 import sys
@@ -77,7 +78,7 @@ class Exceptions:
 
 class AppflowClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html)
     """
 
@@ -87,13 +88,16 @@ class AppflowClient(BaseClient):
     def exceptions(self) -> Exceptions:
         """
         AppflowClient exceptions.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#can_paginate)
         """
 
@@ -111,7 +115,7 @@ class AppflowClient(BaseClient):
         Creates a new connector profile associated with your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.create_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.create_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_connector_profile)
         """
 
@@ -130,7 +134,7 @@ class AppflowClient(BaseClient):
         """
         Enables your application to create a new flow using Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.create_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.create_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#create_flow)
         """
 
@@ -140,7 +144,7 @@ class AppflowClient(BaseClient):
         """
         Enables you to delete an existing connector profile.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.delete_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_connector_profile)
         """
 
@@ -148,7 +152,7 @@ class AppflowClient(BaseClient):
         """
         Enables your application to delete an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.delete_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.delete_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#delete_flow)
         """
 
@@ -159,7 +163,7 @@ class AppflowClient(BaseClient):
         Describes the given custom connector registered in your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_connector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector)
         """
 
@@ -175,7 +179,7 @@ class AppflowClient(BaseClient):
         Provides details regarding the entity used with the connector, with a
         description of the data model for each entity.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_entity)
         """
 
@@ -192,7 +196,7 @@ class AppflowClient(BaseClient):
         Returns a list of `connector-profile` details matching the provided `connector-
         profile` names and `connector-types`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_connector_profiles)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connector_profiles)
         """
 
@@ -206,7 +210,7 @@ class AppflowClient(BaseClient):
         """
         Describes the connectors vended by Amazon AppFlow for specified connector types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_connectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_connectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_connectors)
         """
 
@@ -214,7 +218,7 @@ class AppflowClient(BaseClient):
         """
         Provides a description of the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow)
         """
 
@@ -224,7 +228,7 @@ class AppflowClient(BaseClient):
         """
         Fetches the execution history of the flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_flow_execution_records)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#describe_flow_execution_records)
         """
 
@@ -238,7 +242,7 @@ class AppflowClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#generate_presigned_url)
         """
 
@@ -253,7 +257,7 @@ class AppflowClient(BaseClient):
         """
         Returns the list of available connector entities supported by Amazon AppFlow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_connector_entities)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.list_connector_entities)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connector_entities)
         """
 
@@ -264,7 +268,7 @@ class AppflowClient(BaseClient):
         Returns the list of all registered custom connectors in your Amazon Web Services
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_connectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.list_connectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_connectors)
         """
 
@@ -274,7 +278,7 @@ class AppflowClient(BaseClient):
         """
         Lists all of the flows associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_flows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.list_flows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_flows)
         """
 
@@ -282,7 +286,7 @@ class AppflowClient(BaseClient):
         """
         Retrieves the tags that are associated with a specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#list_tags_for_resource)
         """
 
@@ -297,7 +301,7 @@ class AppflowClient(BaseClient):
         """
         Registers a new connector with your Amazon Web Services account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.register_connector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.register_connector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#register_connector)
         """
 
@@ -305,7 +309,7 @@ class AppflowClient(BaseClient):
         """
         Activates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.start_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.start_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#start_flow)
         """
 
@@ -313,7 +317,7 @@ class AppflowClient(BaseClient):
         """
         Deactivates the existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.stop_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.stop_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#stop_flow)
         """
 
@@ -321,7 +325,7 @@ class AppflowClient(BaseClient):
         """
         Applies a tag to the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#tag_resource)
         """
 
@@ -332,7 +336,7 @@ class AppflowClient(BaseClient):
         Unregisters the custom connector registered in your account that matches the
         connectorLabel provided in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.unregister_connector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.unregister_connector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#unregister_connector)
         """
 
@@ -340,7 +344,7 @@ class AppflowClient(BaseClient):
         """
         Removes a tag from the specified flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#untag_resource)
         """
 
@@ -354,7 +358,7 @@ class AppflowClient(BaseClient):
         """
         Updates a given connector profile associated with your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.update_connector_profile)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.update_connector_profile)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_connector_profile)
         """
 
@@ -371,6 +375,6 @@ class AppflowClient(BaseClient):
         """
         Updates an existing flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.47/reference/services/appflow.html#Appflow.Client.update_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.update_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/client.html#update_flow)
         """
