@@ -17,6 +17,7 @@ from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
     AggregationTypeType,
+    AuthenticationTypeType,
     ConnectionModeType,
     ConnectorTypeType,
     DatadogConnectorOperatorType,
@@ -28,7 +29,9 @@ from .literals import (
     GoogleAnalyticsConnectorOperatorType,
     InforNexusConnectorOperatorType,
     MarketoConnectorOperatorType,
+    OAuth2GrantTypeType,
     OperatorPropertiesKeysType,
+    OperatorsType,
     OperatorType,
     PrefixFormatType,
     PrefixTypeType,
@@ -64,8 +67,12 @@ __all__ = (
     "AggregationConfigTypeDef",
     "AmplitudeConnectorProfileCredentialsTypeDef",
     "AmplitudeSourcePropertiesTypeDef",
+    "ApiKeyCredentialsTypeDef",
+    "AuthParameterTypeDef",
+    "AuthenticationConfigTypeDef",
     "BasicAuthCredentialsTypeDef",
     "ConnectorConfigurationTypeDef",
+    "ConnectorDetailTypeDef",
     "ConnectorEntityFieldTypeDef",
     "ConnectorEntityTypeDef",
     "ConnectorMetadataTypeDef",
@@ -75,10 +82,18 @@ __all__ = (
     "ConnectorProfileCredentialsTypeDef",
     "ConnectorProfilePropertiesTypeDef",
     "ConnectorProfileTypeDef",
+    "ConnectorProvisioningConfigTypeDef",
+    "ConnectorRuntimeSettingTypeDef",
     "CreateConnectorProfileRequestRequestTypeDef",
     "CreateConnectorProfileResponseTypeDef",
     "CreateFlowRequestRequestTypeDef",
     "CreateFlowResponseTypeDef",
+    "CustomAuthConfigTypeDef",
+    "CustomAuthCredentialsTypeDef",
+    "CustomConnectorDestinationPropertiesTypeDef",
+    "CustomConnectorProfileCredentialsTypeDef",
+    "CustomConnectorProfilePropertiesTypeDef",
+    "CustomConnectorSourcePropertiesTypeDef",
     "CustomerProfilesDestinationPropertiesTypeDef",
     "DatadogConnectorProfileCredentialsTypeDef",
     "DatadogConnectorProfilePropertiesTypeDef",
@@ -89,6 +104,8 @@ __all__ = (
     "DescribeConnectorEntityResponseTypeDef",
     "DescribeConnectorProfilesRequestRequestTypeDef",
     "DescribeConnectorProfilesResponseTypeDef",
+    "DescribeConnectorRequestRequestTypeDef",
+    "DescribeConnectorResponseTypeDef",
     "DescribeConnectorsRequestRequestTypeDef",
     "DescribeConnectorsResponseTypeDef",
     "DescribeFlowExecutionRecordsRequestRequestTypeDef",
@@ -119,8 +136,11 @@ __all__ = (
     "InforNexusConnectorProfileCredentialsTypeDef",
     "InforNexusConnectorProfilePropertiesTypeDef",
     "InforNexusSourcePropertiesTypeDef",
+    "LambdaConnectorProvisioningConfigTypeDef",
     "ListConnectorEntitiesRequestRequestTypeDef",
     "ListConnectorEntitiesResponseTypeDef",
+    "ListConnectorsRequestRequestTypeDef",
+    "ListConnectorsResponseTypeDef",
     "ListFlowsRequestRequestTypeDef",
     "ListFlowsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -128,13 +148,19 @@ __all__ = (
     "MarketoConnectorProfileCredentialsTypeDef",
     "MarketoConnectorProfilePropertiesTypeDef",
     "MarketoSourcePropertiesTypeDef",
+    "OAuth2CredentialsTypeDef",
+    "OAuth2DefaultsTypeDef",
+    "OAuth2PropertiesTypeDef",
     "OAuthCredentialsTypeDef",
     "OAuthPropertiesTypeDef",
     "PrefixConfigTypeDef",
     "PrivateConnectionProvisioningStateTypeDef",
+    "RangeTypeDef",
     "RedshiftConnectorProfileCredentialsTypeDef",
     "RedshiftConnectorProfilePropertiesTypeDef",
     "RedshiftDestinationPropertiesTypeDef",
+    "RegisterConnectorRequestRequestTypeDef",
+    "RegisterConnectorResponseTypeDef",
     "ResponseMetadataTypeDef",
     "S3DestinationPropertiesTypeDef",
     "S3InputFormatConfigTypeDef",
@@ -176,6 +202,7 @@ __all__ = (
     "TrendmicroSourcePropertiesTypeDef",
     "TriggerConfigTypeDef",
     "TriggerPropertiesTypeDef",
+    "UnregisterConnectorRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateConnectorProfileRequestRequestTypeDef",
     "UpdateConnectorProfileResponseTypeDef",
@@ -216,6 +243,53 @@ AmplitudeSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+_RequiredApiKeyCredentialsTypeDef = TypedDict(
+    "_RequiredApiKeyCredentialsTypeDef",
+    {
+        "apiKey": str,
+    },
+)
+_OptionalApiKeyCredentialsTypeDef = TypedDict(
+    "_OptionalApiKeyCredentialsTypeDef",
+    {
+        "apiSecretKey": str,
+    },
+    total=False,
+)
+
+
+class ApiKeyCredentialsTypeDef(
+    _RequiredApiKeyCredentialsTypeDef, _OptionalApiKeyCredentialsTypeDef
+):
+    pass
+
+
+AuthParameterTypeDef = TypedDict(
+    "AuthParameterTypeDef",
+    {
+        "key": str,
+        "isRequired": bool,
+        "label": str,
+        "description": str,
+        "isSensitiveField": bool,
+        "connectorSuppliedValues": List[str],
+    },
+    total=False,
+)
+
+AuthenticationConfigTypeDef = TypedDict(
+    "AuthenticationConfigTypeDef",
+    {
+        "isBasicAuthSupported": bool,
+        "isApiKeyAuthSupported": bool,
+        "isOAuth2Supported": bool,
+        "isCustomAuthSupported": bool,
+        "oAuth2Defaults": "OAuth2DefaultsTypeDef",
+        "customAuthConfigs": List["CustomAuthConfigTypeDef"],
+    },
+    total=False,
+)
+
 BasicAuthCredentialsTypeDef = TypedDict(
     "BasicAuthCredentialsTypeDef",
     {
@@ -235,6 +309,42 @@ ConnectorConfigurationTypeDef = TypedDict(
         "isPrivateLinkEndpointUrlRequired": bool,
         "supportedTriggerTypes": List[TriggerTypeType],
         "connectorMetadata": "ConnectorMetadataTypeDef",
+        "connectorType": ConnectorTypeType,
+        "connectorLabel": str,
+        "connectorDescription": str,
+        "connectorOwner": str,
+        "connectorName": str,
+        "connectorVersion": str,
+        "connectorArn": str,
+        "connectorModes": List[str],
+        "authenticationConfig": "AuthenticationConfigTypeDef",
+        "connectorRuntimeSettings": List["ConnectorRuntimeSettingTypeDef"],
+        "supportedApiVersions": List[str],
+        "supportedOperators": List[OperatorsType],
+        "supportedWriteOperations": List[WriteOperationTypeType],
+        "connectorProvisioningType": Literal["LAMBDA"],
+        "connectorProvisioningConfig": "ConnectorProvisioningConfigTypeDef",
+        "logoURL": str,
+        "registeredAt": datetime,
+        "registeredBy": str,
+    },
+    total=False,
+)
+
+ConnectorDetailTypeDef = TypedDict(
+    "ConnectorDetailTypeDef",
+    {
+        "connectorDescription": str,
+        "connectorName": str,
+        "connectorOwner": str,
+        "connectorVersion": str,
+        "applicationType": str,
+        "connectorType": ConnectorTypeType,
+        "connectorLabel": str,
+        "registeredAt": datetime,
+        "registeredBy": str,
+        "connectorProvisioningType": Literal["LAMBDA"],
+        "connectorModes": List[str],
     },
     total=False,
 )
@@ -248,11 +358,16 @@ _RequiredConnectorEntityFieldTypeDef = TypedDict(
 _OptionalConnectorEntityFieldTypeDef = TypedDict(
     "_OptionalConnectorEntityFieldTypeDef",
     {
+        "parentIdentifier": str,
         "label": str,
+        "isPrimaryKey": bool,
+        "defaultValue": str,
+        "isDeprecated": bool,
         "supportedFieldTypeDetails": "SupportedFieldTypeDetailsTypeDef",
         "description": str,
         "sourceProperties": "SourceFieldPropertiesTypeDef",
         "destinationProperties": "DestinationFieldPropertiesTypeDef",
+        "customProperties": Dict[str, str],
     },
     total=False,
 )
@@ -339,6 +454,7 @@ ConnectorOperatorTypeDef = TypedDict(
         "Veeva": VeevaConnectorOperatorType,
         "Zendesk": ZendeskConnectorOperatorType,
         "SAPOData": SAPODataConnectorOperatorType,
+        "CustomConnector": OperatorType,
     },
     total=False,
 )
@@ -371,6 +487,7 @@ ConnectorProfileCredentialsTypeDef = TypedDict(
         "Veeva": "VeevaConnectorProfileCredentialsTypeDef",
         "Zendesk": "ZendeskConnectorProfileCredentialsTypeDef",
         "SAPOData": "SAPODataConnectorProfileCredentialsTypeDef",
+        "CustomConnector": "CustomConnectorProfileCredentialsTypeDef",
     },
     total=False,
 )
@@ -395,6 +512,7 @@ ConnectorProfilePropertiesTypeDef = TypedDict(
         "Veeva": "VeevaConnectorProfilePropertiesTypeDef",
         "Zendesk": "ZendeskConnectorProfilePropertiesTypeDef",
         "SAPOData": "SAPODataConnectorProfilePropertiesTypeDef",
+        "CustomConnector": "CustomConnectorProfilePropertiesTypeDef",
     },
     total=False,
 )
@@ -405,6 +523,7 @@ ConnectorProfileTypeDef = TypedDict(
         "connectorProfileArn": str,
         "connectorProfileName": str,
         "connectorType": ConnectorTypeType,
+        "connectorLabel": str,
         "connectionMode": ConnectionModeType,
         "credentialsArn": str,
         "connectorProfileProperties": "ConnectorProfilePropertiesTypeDef",
@@ -415,6 +534,28 @@ ConnectorProfileTypeDef = TypedDict(
     total=False,
 )
 
+ConnectorProvisioningConfigTypeDef = TypedDict(
+    "ConnectorProvisioningConfigTypeDef",
+    {
+        "lambda": "LambdaConnectorProvisioningConfigTypeDef",
+    },
+    total=False,
+)
+
+ConnectorRuntimeSettingTypeDef = TypedDict(
+    "ConnectorRuntimeSettingTypeDef",
+    {
+        "key": str,
+        "dataType": str,
+        "isRequired": bool,
+        "label": str,
+        "description": str,
+        "scope": str,
+        "connectorSuppliedValueOptions": List[str],
+    },
+    total=False,
+)
+
 _RequiredCreateConnectorProfileRequestRequestTypeDef = TypedDict(
     "_RequiredCreateConnectorProfileRequestRequestTypeDef",
     {
@@ -428,6 +569,7 @@ _OptionalCreateConnectorProfileRequestRequestTypeDef = TypedDict(
     "_OptionalCreateConnectorProfileRequestRequestTypeDef",
     {
         "kmsArn": str,
+        "connectorLabel": str,
     },
     total=False,
 )
@@ -484,6 +626,116 @@ CreateFlowResponseTypeDef = TypedDict(
     },
 )
 
+CustomAuthConfigTypeDef = TypedDict(
+    "CustomAuthConfigTypeDef",
+    {
+        "customAuthenticationType": str,
+        "authParameters": List["AuthParameterTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredCustomAuthCredentialsTypeDef = TypedDict(
+    "_RequiredCustomAuthCredentialsTypeDef",
+    {
+        "customAuthenticationType": str,
+    },
+)
+_OptionalCustomAuthCredentialsTypeDef = TypedDict(
+    "_OptionalCustomAuthCredentialsTypeDef",
+    {
+        "credentialsMap": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CustomAuthCredentialsTypeDef(
+    _RequiredCustomAuthCredentialsTypeDef, _OptionalCustomAuthCredentialsTypeDef
+):
+    pass
+
+
+_RequiredCustomConnectorDestinationPropertiesTypeDef = TypedDict(
+    "_RequiredCustomConnectorDestinationPropertiesTypeDef",
+    {
+        "entityName": str,
+    },
+)
+_OptionalCustomConnectorDestinationPropertiesTypeDef = TypedDict(
+    "_OptionalCustomConnectorDestinationPropertiesTypeDef",
+    {
+        "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
+        "writeOperationType": WriteOperationTypeType,
+        "idFieldNames": Sequence[str],
+        "customProperties": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CustomConnectorDestinationPropertiesTypeDef(
+    _RequiredCustomConnectorDestinationPropertiesTypeDef,
+    _OptionalCustomConnectorDestinationPropertiesTypeDef,
+):
+    pass
+
+
+_RequiredCustomConnectorProfileCredentialsTypeDef = TypedDict(
+    "_RequiredCustomConnectorProfileCredentialsTypeDef",
+    {
+        "authenticationType": AuthenticationTypeType,
+    },
+)
+_OptionalCustomConnectorProfileCredentialsTypeDef = TypedDict(
+    "_OptionalCustomConnectorProfileCredentialsTypeDef",
+    {
+        "basic": "BasicAuthCredentialsTypeDef",
+        "oauth2": "OAuth2CredentialsTypeDef",
+        "apiKey": "ApiKeyCredentialsTypeDef",
+        "custom": "CustomAuthCredentialsTypeDef",
+    },
+    total=False,
+)
+
+
+class CustomConnectorProfileCredentialsTypeDef(
+    _RequiredCustomConnectorProfileCredentialsTypeDef,
+    _OptionalCustomConnectorProfileCredentialsTypeDef,
+):
+    pass
+
+
+CustomConnectorProfilePropertiesTypeDef = TypedDict(
+    "CustomConnectorProfilePropertiesTypeDef",
+    {
+        "profileProperties": Mapping[str, str],
+        "oAuth2Properties": "OAuth2PropertiesTypeDef",
+    },
+    total=False,
+)
+
+_RequiredCustomConnectorSourcePropertiesTypeDef = TypedDict(
+    "_RequiredCustomConnectorSourcePropertiesTypeDef",
+    {
+        "entityName": str,
+    },
+)
+_OptionalCustomConnectorSourcePropertiesTypeDef = TypedDict(
+    "_OptionalCustomConnectorSourcePropertiesTypeDef",
+    {
+        "customProperties": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CustomConnectorSourcePropertiesTypeDef(
+    _RequiredCustomConnectorSourcePropertiesTypeDef, _OptionalCustomConnectorSourcePropertiesTypeDef
+):
+    pass
+
+
 _RequiredCustomerProfilesDestinationPropertiesTypeDef = TypedDict(
     "_RequiredCustomerProfilesDestinationPropertiesTypeDef",
     {
@@ -582,6 +834,7 @@ _OptionalDescribeConnectorEntityRequestRequestTypeDef = TypedDict(
     {
         "connectorType": ConnectorTypeType,
         "connectorProfileName": str,
+        "apiVersion": str,
     },
     total=False,
 )
@@ -607,6 +860,7 @@ DescribeConnectorProfilesRequestRequestTypeDef = TypedDict(
     {
         "connectorProfileNames": Sequence[str],
         "connectorType": ConnectorTypeType,
+        "connectorLabel": str,
         "maxResults": int,
         "nextToken": str,
     },
@@ -622,10 +876,40 @@ DescribeConnectorProfilesResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredDescribeConnectorRequestRequestTypeDef = TypedDict(
+    "_RequiredDescribeConnectorRequestRequestTypeDef",
+    {
+        "connectorType": ConnectorTypeType,
+    },
+)
+_OptionalDescribeConnectorRequestRequestTypeDef = TypedDict(
+    "_OptionalDescribeConnectorRequestRequestTypeDef",
+    {
+        "connectorLabel": str,
+    },
+    total=False,
+)
+
+
+class DescribeConnectorRequestRequestTypeDef(
+    _RequiredDescribeConnectorRequestRequestTypeDef, _OptionalDescribeConnectorRequestRequestTypeDef
+):
+    pass
+
+
+DescribeConnectorResponseTypeDef = TypedDict(
+    "DescribeConnectorResponseTypeDef",
+    {
+        "connectorConfiguration": "ConnectorConfigurationTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeConnectorsRequestRequestTypeDef = TypedDict(
     "DescribeConnectorsRequestRequestTypeDef",
     {
         "connectorTypes": Sequence[ConnectorTypeType],
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
@@ -635,6 +919,7 @@ DescribeConnectorsResponseTypeDef = TypedDict(
     "DescribeConnectorsResponseTypeDef",
     {
         "connectorConfigurations": Dict[ConnectorTypeType, "ConnectorConfigurationTypeDef"],
+        "connectors": List["ConnectorDetailTypeDef"],
         "nextToken": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
@@ -715,6 +1000,7 @@ DestinationConnectorPropertiesTypeDef = TypedDict(
         "Honeycode": "HoneycodeDestinationPropertiesTypeDef",
         "CustomerProfiles": "CustomerProfilesDestinationPropertiesTypeDef",
         "Zendesk": "ZendeskDestinationPropertiesTypeDef",
+        "CustomConnector": "CustomConnectorDestinationPropertiesTypeDef",
     },
     total=False,
 )
@@ -726,6 +1012,7 @@ DestinationFieldPropertiesTypeDef = TypedDict(
         "isNullable": bool,
         "isUpsertable": bool,
         "isUpdatable": bool,
+        "isDefaultedOnCreate": bool,
         "supportedWriteOperations": List[WriteOperationTypeType],
     },
     total=False,
@@ -741,6 +1028,7 @@ _RequiredDestinationFlowConfigTypeDef = TypedDict(
 _OptionalDestinationFlowConfigTypeDef = TypedDict(
     "_OptionalDestinationFlowConfigTypeDef",
     {
+        "apiVersion": str,
         "connectorProfileName": str,
     },
     total=False,
@@ -861,6 +1149,10 @@ _OptionalFieldTypeDetailsTypeDef = TypedDict(
     "_OptionalFieldTypeDetailsTypeDef",
     {
         "supportedValues": List[str],
+        "valueRegexPattern": str,
+        "supportedDateFormat": str,
+        "fieldValueRange": "RangeTypeDef",
+        "fieldLengthRange": "RangeTypeDef",
     },
     total=False,
 )
@@ -878,7 +1170,9 @@ FlowDefinitionTypeDef = TypedDict(
         "flowName": str,
         "flowStatus": FlowStatusType,
         "sourceConnectorType": ConnectorTypeType,
+        "sourceConnectorLabel": str,
         "destinationConnectorType": ConnectorTypeType,
+        "destinationConnectorLabel": str,
         "triggerType": TriggerTypeType,
         "createdAt": datetime,
         "lastUpdatedAt": datetime,
@@ -1001,12 +1295,20 @@ InforNexusSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+LambdaConnectorProvisioningConfigTypeDef = TypedDict(
+    "LambdaConnectorProvisioningConfigTypeDef",
+    {
+        "lambdaArn": str,
+    },
+)
+
 ListConnectorEntitiesRequestRequestTypeDef = TypedDict(
     "ListConnectorEntitiesRequestRequestTypeDef",
     {
         "connectorProfileName": str,
         "connectorType": ConnectorTypeType,
         "entitiesPath": str,
+        "apiVersion": str,
     },
     total=False,
 )
@@ -1019,6 +1321,24 @@ ListConnectorEntitiesResponseTypeDef = TypedDict(
     },
 )
 
+ListConnectorsRequestRequestTypeDef = TypedDict(
+    "ListConnectorsRequestRequestTypeDef",
+    {
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+ListConnectorsResponseTypeDef = TypedDict(
+    "ListConnectorsResponseTypeDef",
+    {
+        "connectors": List["ConnectorDetailTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListFlowsRequestRequestTypeDef = TypedDict(
     "ListFlowsRequestRequestTypeDef",
     {
@@ -1090,6 +1410,37 @@ MarketoSourcePropertiesTypeDef = TypedDict(
     },
 )
 
+OAuth2CredentialsTypeDef = TypedDict(
+    "OAuth2CredentialsTypeDef",
+    {
+        "clientId": str,
+        "clientSecret": str,
+        "accessToken": str,
+        "refreshToken": str,
+        "oAuthRequest": "ConnectorOAuthRequestTypeDef",
+    },
+    total=False,
+)
+
+OAuth2DefaultsTypeDef = TypedDict(
+    "OAuth2DefaultsTypeDef",
+    {
+        "oauthScopes": List[str],
+        "tokenUrls": List[str],
+        "authCodeUrls": List[str],
+        "oauth2GrantTypesSupported": List[OAuth2GrantTypeType],
+    },
+    total=False,
+)
+
+OAuth2PropertiesTypeDef = TypedDict(
+    "OAuth2PropertiesTypeDef",
+    {
+        "tokenUrl": str,
+        "oAuth2GrantType": OAuth2GrantTypeType,
+    },
+)
+
 _RequiredOAuthCredentialsTypeDef = TypedDict(
     "_RequiredOAuthCredentialsTypeDef",
     {
@@ -1140,6 +1491,15 @@ PrivateConnectionProvisioningStateTypeDef = TypedDict(
     total=False,
 )
 
+RangeTypeDef = TypedDict(
+    "RangeTypeDef",
+    {
+        "maximum": float,
+        "minimum": float,
+    },
+    total=False,
+)
+
 RedshiftConnectorProfileCredentialsTypeDef = TypedDict(
     "RedshiftConnectorProfileCredentialsTypeDef",
     {
@@ -1195,6 +1555,25 @@ class RedshiftDestinationPropertiesTypeDef(
     pass
 
 
+RegisterConnectorRequestRequestTypeDef = TypedDict(
+    "RegisterConnectorRequestRequestTypeDef",
+    {
+        "connectorLabel": str,
+        "description": str,
+        "connectorProvisioningType": Literal["LAMBDA"],
+        "connectorProvisioningConfig": "ConnectorProvisioningConfigTypeDef",
+    },
+    total=False,
+)
+
+RegisterConnectorResponseTypeDef = TypedDict(
+    "RegisterConnectorResponseTypeDef",
+    {
+        "connectorArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ResponseMetadataTypeDef = TypedDict(
     "ResponseMetadataTypeDef",
     {
@@ -1577,6 +1956,7 @@ SourceConnectorPropertiesTypeDef = TypedDict(
         "Veeva": "VeevaSourcePropertiesTypeDef",
         "Zendesk": "ZendeskSourcePropertiesTypeDef",
         "SAPOData": "SAPODataSourcePropertiesTypeDef",
+        "CustomConnector": "CustomConnectorSourcePropertiesTypeDef",
     },
     total=False,
 )
@@ -1586,6 +1966,7 @@ SourceFieldPropertiesTypeDef = TypedDict(
     {
         "isRetrievable": bool,
         "isQueryable": bool,
+        "isTimestampFieldForIncrementalQueries": bool,
     },
     total=False,
 )
@@ -1600,6 +1981,7 @@ _RequiredSourceFlowConfigTypeDef = TypedDict(
 _OptionalSourceFlowConfigTypeDef = TypedDict(
     "_OptionalSourceFlowConfigTypeDef",
     {
+        "apiVersion": str,
         "connectorProfileName": str,
         "incrementalPullConfig": "IncrementalPullConfigTypeDef",
     },
@@ -1722,6 +2104,28 @@ TriggerPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredUnregisterConnectorRequestRequestTypeDef = TypedDict(
+    "_RequiredUnregisterConnectorRequestRequestTypeDef",
+    {
+        "connectorLabel": str,
+    },
+)
+_OptionalUnregisterConnectorRequestRequestTypeDef = TypedDict(
+    "_OptionalUnregisterConnectorRequestRequestTypeDef",
+    {
+        "forceDelete": bool,
+    },
+    total=False,
+)
+
+
+class UnregisterConnectorRequestRequestTypeDef(
+    _RequiredUnregisterConnectorRequestRequestTypeDef,
+    _OptionalUnregisterConnectorRequestRequestTypeDef,
+):
+    pass
+
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
